@@ -1,7 +1,7 @@
 #
 #   Proxy minion metaproxy modules
 #
-
+import concurrent.futures
 import copy
 import logging
 import os
@@ -96,9 +96,11 @@ def post_master_init(self, master):
     if "proxy" not in self.opts:
         self.opts["proxy"] = self.opts["pillar"]["proxy"]
 
+    pillar = copy.deepcopy(self.opts["pillar"])
+    pillar.pop("master", None)
     self.opts = salt.utils.dictupdate.merge(
         self.opts,
-        self.opts["pillar"],
+        pillar,
         strategy=self.opts.get("proxy_merge_pillar_in_opts_strategy"),
         merge_lists=self.opts.get("proxy_deep_merge_pillar_in_opts", False),
     )
@@ -231,10 +233,11 @@ def post_master_init(self, master):
                 }
             },
             persist=True,
+            fire_event=False,
         )
         log.info("Added mine.update to scheduler")
     else:
-        self.schedule.delete_job("__mine_interval", persist=True)
+        self.schedule.delete_job("__mine_interval", persist=True, fire_event=False)
 
     # add master_alive job if enabled
     if self.opts["transport"] != "tcp" and self.opts["master_alive_interval"] > 0:
@@ -250,6 +253,7 @@ def post_master_init(self, master):
                 }
             },
             persist=True,
+            fire_event=False,
         )
         if (
             self.opts["master_failback"]
@@ -268,18 +272,24 @@ def post_master_init(self, master):
                     }
                 },
                 persist=True,
+                fire_event=False,
             )
         else:
             self.schedule.delete_job(
-                salt.minion.master_event(type="failback"), persist=True
+                salt.minion.master_event(type="failback"),
+                persist=True,
+                fire_event=False,
             )
     else:
         self.schedule.delete_job(
             salt.minion.master_event(type="alive", master=self.opts["master"]),
             persist=True,
+            fire_event=False,
         )
         self.schedule.delete_job(
-            salt.minion.master_event(type="failback"), persist=True
+            salt.minion.master_event(type="failback"),
+            persist=True,
+            fire_event=False,
         )
 
     # proxy keepalive
@@ -304,10 +314,15 @@ def post_master_init(self, master):
                 }
             },
             persist=True,
+            fire_event=False,
         )
-        self.schedule.enable_schedule()
+        self.schedule.enable_schedule(fire_event=False)
     else:
-        self.schedule.delete_job("__proxy_keepalive", persist=True)
+        self.schedule.delete_job(
+            "__proxy_keepalive",
+            persist=True,
+            fire_event=False,
+        )
 
     #  Sync the grains here so the proxy can communicate them to the master
     self.functions["saltutil.sync_grains"](saltenv="base")
@@ -320,171 +335,254 @@ def post_master_init(self, master):
     self.proxy_pillar = {}
     self.proxy_context = {}
     self.add_periodic_callback("cleanup", self.cleanup_subprocesses)
-    for _id in self.opts["proxy"].get("ids", []):
-        control_id = self.opts["id"]
-        proxyopts = self.opts.copy()
-        proxyopts["id"] = _id
 
-        proxyopts = salt.config.proxy_config(
-            self.opts["conf_file"], defaults=proxyopts, minion_id=_id
-        )
-        proxyopts["id"] = proxyopts["proxyid"] = _id
+    _failed = list()
+    if self.opts["proxy"].get("parallel_startup"):
+        log.debug("Initiating parallel startup for proxies")
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            futures = {
+                executor.submit(
+                    subproxy_post_master_init,
+                    _id,
+                    uid,
+                    self.opts,
+                    self.proxy,
+                    self.utils,
+                ): _id
+                for _id in self.opts["proxy"].get("ids", [])
+            }
 
-        proxyopts["subproxy"] = True
+        for future in concurrent.futures.as_completed(futures):
+            try:
+                sub_proxy_data = future.result()
+            except Exception as exc:  # pylint: disable=broad-except
+                _id = futures[future]
+                log.info(
+                    "An exception occured during initialization for %s, skipping: %s",
+                    _id,
+                    exc,
+                )
+                _failed.append(_id)
+                continue
+            minion_id = sub_proxy_data["proxy_opts"].get("id")
 
-        self.proxy_context[_id] = {"proxy_id": _id}
+            if sub_proxy_data["proxy_minion"]:
+                self.deltaproxy_opts[minion_id] = sub_proxy_data["proxy_opts"]
+                self.deltaproxy_objs[minion_id] = sub_proxy_data["proxy_minion"]
 
-        # We need grains first to be able to load pillar, which is where we keep the proxy
-        # configurations
-        self.proxy_grains[_id] = salt.loader.grains(
-            proxyopts, proxy=self.proxy, context=self.proxy_context[_id]
-        )
-        self.proxy_pillar[_id] = yield salt.pillar.get_async_pillar(
-            proxyopts,
-            self.proxy_grains[_id],
-            _id,
-            saltenv=proxyopts["saltenv"],
-            pillarenv=proxyopts.get("pillarenv"),
-        ).compile_pillar()
+                if self.deltaproxy_opts[minion_id] and self.deltaproxy_objs[minion_id]:
+                    self.deltaproxy_objs[
+                        minion_id
+                    ].req_channel = salt.channel.client.AsyncReqChannel.factory(
+                        sub_proxy_data["proxy_opts"], io_loop=self.io_loop
+                    )
+    else:
+        log.debug("Initiating non-parallel startup for proxies")
+        for _id in self.opts["proxy"].get("ids", []):
+            try:
+                sub_proxy_data = subproxy_post_master_init(
+                    _id, uid, self.opts, self.proxy, self.utils
+                )
+            except Exception as exc:  # pylint: disable=broad-except
+                log.info(
+                    "An exception occured during initialization for %s, skipping: %s",
+                    _id,
+                    exc,
+                )
+                _failed.append(_id)
+                continue
+            minion_id = sub_proxy_data["proxy_opts"].get("id")
 
-        proxyopts["proxy"] = self.proxy_pillar[_id].get("proxy", {})
-        if not proxyopts["proxy"]:
-            log.warning(
-                "Pillar data for proxy minion %s could not be loaded, skipping.", _id
-            )
-            continue
+            if sub_proxy_data["proxy_minion"]:
+                self.deltaproxy_opts[minion_id] = sub_proxy_data["proxy_opts"]
+                self.deltaproxy_objs[minion_id] = sub_proxy_data["proxy_minion"]
 
-        # Remove ids
-        proxyopts["proxy"].pop("ids", None)
-
-        proxyopts["pillar"] = self.proxy_pillar[_id]
-        proxyopts["grains"] = self.proxy_grains[_id]
-
-        proxyopts["hash_id"] = self.opts["id"]
-
-        _proxy_minion = ProxyMinion(proxyopts)
-        _proxy_minion.proc_dir = salt.minion.get_proc_dir(
-            proxyopts["cachedir"], uid=uid
-        )
-
-        _proxy_minion.proxy = salt.loader.proxy(
-            proxyopts, utils=self.utils, context=self.proxy_context[_id]
-        )
-        _proxy_minion.subprocess_list = self.subprocess_list
-
-        # a long-running req channel
-        _proxy_minion.req_channel = salt.transport.client.AsyncReqChannel.factory(
-            proxyopts, io_loop=self.io_loop
-        )
-
-        # And load the modules
-        (
-            _proxy_minion.functions,
-            _proxy_minion.returners,
-            _proxy_minion.function_errors,
-            _proxy_minion.executors,
-        ) = _proxy_minion._load_modules(
-            opts=proxyopts, grains=proxyopts["grains"], context=self.proxy_context[_id]
-        )
-
-        # we can then sync any proxymodules down from the master
-        # we do a sync_all here in case proxy code was installed by
-        # SPM or was manually placed in /srv/salt/_modules etc.
-        _proxy_minion.functions["saltutil.sync_all"](saltenv=self.opts["saltenv"])
-
-        # And re-load the modules so the __proxy__ variable gets injected
-        (
-            _proxy_minion.functions,
-            _proxy_minion.returners,
-            _proxy_minion.function_errors,
-            _proxy_minion.executors,
-        ) = _proxy_minion._load_modules(
-            opts=proxyopts, grains=proxyopts["grains"], context=self.proxy_context[_id]
-        )
-
-        _proxy_minion.functions.pack["__proxy__"] = _proxy_minion.proxy
-        _proxy_minion.proxy.pack["__salt__"] = _proxy_minion.functions
-        _proxy_minion.proxy.pack["__ret__"] = _proxy_minion.returners
-        _proxy_minion.proxy.pack["__pillar__"] = proxyopts["pillar"]
-        _proxy_minion.proxy.pack["__grains__"] = proxyopts["grains"]
-
-        # Reload utils as well (chicken and egg, __utils__ needs __proxy__ and __proxy__ needs __utils__
-        _proxy_minion.proxy.utils = salt.loader.utils(
-            proxyopts, proxy=_proxy_minion.proxy, context=self.proxy_context[_id]
-        )
-
-        _proxy_minion.proxy.pack["__utils__"] = _proxy_minion.proxy.utils
-
-        # Reload all modules so all dunder variables are injected
-        _proxy_minion.proxy.reload_modules()
-
-        _proxy_minion.connected = True
-
-        _fq_proxyname = proxyopts["proxy"]["proxytype"]
-
-        proxy_init_fn = _proxy_minion.proxy[_fq_proxyname + ".init"]
-        try:
-            proxy_init_fn(proxyopts)
-        except Exception as exc:  # pylint: disable=broad-except
-            log.error(
-                "An exception occured during the initialization of minion %s: %s",
-                _id,
-                exc,
-                exc_info=True,
-            )
-            continue
-
-        # Reload the grains
-        self.proxy_grains[_id] = salt.loader.grains(
-            proxyopts, proxy=_proxy_minion.proxy, context=self.proxy_context[_id]
-        )
-        proxyopts["grains"] = self.proxy_grains[_id]
-
-        if not hasattr(_proxy_minion, "schedule"):
-            _proxy_minion.schedule = salt.utils.schedule.Schedule(
-                proxyopts,
-                _proxy_minion.functions,
-                _proxy_minion.returners,
-                cleanup=[salt.minion.master_event(type="alive")],
-                proxy=_proxy_minion.proxy,
-                new_instance=True,
-                _subprocess_list=_proxy_minion.subprocess_list,
-            )
-
-        self.deltaproxy_objs[_id] = _proxy_minion
-        self.deltaproxy_opts[_id] = copy.deepcopy(proxyopts)
-
-        # proxy keepalive
-        _proxy_alive_fn = _fq_proxyname + ".alive"
-        if (
-            _proxy_alive_fn in _proxy_minion.proxy
-            and "status.proxy_reconnect" in self.deltaproxy_objs[_id].functions
-            and proxyopts.get("proxy_keep_alive", True)
-        ):
-            # if `proxy_keep_alive` is either not specified, either set to False does not retry reconnecting
-            _proxy_minion.schedule.add_job(
-                {
-                    "__proxy_keepalive": {
-                        "function": "status.proxy_reconnect",
-                        "minutes": proxyopts.get(
-                            "proxy_keep_alive_interval", 1
-                        ),  # by default, check once per minute
-                        "jid_include": True,
-                        "maxrunning": 1,
-                        "return_job": False,
-                        "kwargs": {"proxy_name": _fq_proxyname},
-                    }
-                },
-                persist=True,
-            )
-            _proxy_minion.schedule.enable_schedule()
-        else:
-            _proxy_minion.schedule.delete_job("__proxy_keepalive", persist=True)
+                if self.deltaproxy_opts[minion_id] and self.deltaproxy_objs[minion_id]:
+                    self.deltaproxy_objs[
+                        minion_id
+                    ].req_channel = salt.channel.client.AsyncReqChannel.factory(
+                        sub_proxy_data["proxy_opts"], io_loop=self.io_loop
+                    )
 
+    if _failed:
+        log.info("Following sub proxies failed %s", _failed)
     self.ready = True
 
 
-def target(cls, minion_instance, opts, data, connected):
+def subproxy_post_master_init(minion_id, uid, opts, main_proxy, main_utils):
+    """
+    Function to finish init after a deltaproxy proxy
+    minion has finished connecting to a master.
+
+    This is primarily loading modules, pillars, etc. (since they need
+    to know which master they connected to) for the sub proxy minions.
+    """
+    proxy_grains = {}
+    proxy_pillar = {}
+
+    proxyopts = opts.copy()
+    proxyopts["id"] = minion_id
+
+    proxyopts = salt.config.proxy_config(
+        opts["conf_file"], defaults=proxyopts, minion_id=minion_id
+    )
+    proxyopts.update({"id": minion_id, "proxyid": minion_id, "subproxy": True})
+
+    proxy_context = {"proxy_id": minion_id}
+
+    # We need grains first to be able to load pillar, which is where we keep the proxy
+    # configurations
+    proxy_grains = salt.loader.grains(
+        proxyopts, proxy=main_proxy, context=proxy_context
+    )
+    proxy_pillar = salt.pillar.get_pillar(
+        proxyopts,
+        proxy_grains,
+        minion_id,
+        saltenv=proxyopts["saltenv"],
+        pillarenv=proxyopts.get("pillarenv"),
+    ).compile_pillar()
+
+    proxyopts["proxy"] = proxy_pillar.get("proxy", {})
+    if not proxyopts["proxy"]:
+        log.warning(
+            "Pillar data for proxy minion %s could not be loaded, skipping.", minion_id
+        )
+        return {"proxy_minion": None, "proxy_opts": {}}
+
+    # Remove ids
+    proxyopts["proxy"].pop("ids", None)
+
+    proxyopts.update(
+        {
+            "pillar": proxy_pillar,
+            "grains": proxy_grains,
+            "hash_id": opts["id"],
+        }
+    )
+
+    _proxy_minion = ProxyMinion(proxyopts)
+    _proxy_minion.proc_dir = salt.minion.get_proc_dir(proxyopts["cachedir"], uid=uid)
+
+    # And load the modules
+    (
+        _proxy_minion.functions,
+        _proxy_minion.returners,
+        _proxy_minion.function_errors,
+        _proxy_minion.executors,
+    ) = _proxy_minion._load_modules(
+        opts=proxyopts,
+        grains=proxyopts["grains"],
+        context=proxy_context,
+    )
+
+    # we can then sync any proxymodules down from the master
+    # we do a sync_all here in case proxy code was installed by
+    # SPM or was manually placed in /srv/salt/_modules etc.
+    _proxy_minion.functions["saltutil.sync_all"](saltenv=opts["saltenv"])
+
+    # And re-load the modules so the __proxy__ variable gets injected
+    (
+        _proxy_minion.functions,
+        _proxy_minion.returners,
+        _proxy_minion.function_errors,
+        _proxy_minion.executors,
+    ) = _proxy_minion._load_modules(
+        opts=proxyopts,
+        grains=proxyopts["grains"],
+        context=proxy_context,
+    )
+
+    # Create this after modules are synced to ensure
+    # any custom modules, eg. custom proxy modules
+    # are avaiable.
+    _proxy_minion.proxy = salt.loader.proxy(
+        proxyopts, utils=main_utils, context=proxy_context
+    )
+
+    _proxy_minion.functions.pack["__proxy__"] = _proxy_minion.proxy
+    _proxy_minion.proxy.pack["__salt__"] = _proxy_minion.functions
+    _proxy_minion.proxy.pack["__ret__"] = _proxy_minion.returners
+    _proxy_minion.proxy.pack["__pillar__"] = proxyopts["pillar"]
+    _proxy_minion.proxy.pack["__grains__"] = proxyopts["grains"]
+
+    # Reload utils as well (chicken and egg, __utils__ needs __proxy__ and __proxy__ needs __utils__
+    _proxy_minion.proxy.utils = salt.loader.utils(
+        proxyopts, proxy=_proxy_minion.proxy, context=proxy_context
+    )
+
+    _proxy_minion.proxy.pack["__utils__"] = _proxy_minion.proxy.utils
+
+    # Reload all modules so all dunder variables are injected
+    _proxy_minion.proxy.reload_modules()
+
+    _proxy_minion.connected = True
+
+    _fq_proxyname = proxyopts["proxy"]["proxytype"]
+
+    proxy_init_fn = _proxy_minion.proxy[_fq_proxyname + ".init"]
+    try:
+        proxy_init_fn(proxyopts)
+    except Exception as exc:  # pylint: disable=broad-except
+        log.error(
+            "An exception occured during the initialization of minion %s: %s",
+            minion_id,
+            exc,
+            exc_info=True,
+        )
+        return {"proxy_minion": None, "proxy_opts": {}}
+
+    # Reload the grains
+    proxy_grains = salt.loader.grains(
+        proxyopts, proxy=_proxy_minion.proxy, context=proxy_context
+    )
+    proxyopts["grains"] = proxy_grains
+
+    if not hasattr(_proxy_minion, "schedule"):
+        _proxy_minion.schedule = salt.utils.schedule.Schedule(
+            proxyopts,
+            _proxy_minion.functions,
+            _proxy_minion.returners,
+            cleanup=[salt.minion.master_event(type="alive")],
+            proxy=_proxy_minion.proxy,
+            new_instance=True,
+            _subprocess_list=_proxy_minion.subprocess_list,
+        )
+
+    # proxy keepalive
+    _proxy_alive_fn = _fq_proxyname + ".alive"
+    if (
+        _proxy_alive_fn in _proxy_minion.proxy
+        and "status.proxy_reconnect" in _proxy_minion.functions
+        and proxyopts.get("proxy_keep_alive", True)
+    ):
+        # if `proxy_keep_alive` is either not specified, either set to False does not retry reconnecting
+        _proxy_minion.schedule.add_job(
+            {
+                "__proxy_keepalive": {
+                    "function": "status.proxy_reconnect",
+                    "minutes": proxyopts.get(
+                        "proxy_keep_alive_interval", 1
+                    ),  # by default, check once per minute
+                    "jid_include": True,
+                    "maxrunning": 1,
+                    "return_job": False,
+                    "kwargs": {"proxy_name": _fq_proxyname},
+                }
+            },
+            persist=True,
+            fire_event=False,
+        )
+        _proxy_minion.schedule.enable_schedule(fire_event=False)
+    else:
+        _proxy_minion.schedule.delete_job(
+            "__proxy_keepalive", persist=True, fire_event=False
+        )
+
+    return {"proxy_minion": _proxy_minion, "proxy_opts": proxyopts}
+
+
+def target(cls, minion_instance, opts, data, connected, creds_map):
     """
     Handle targeting of the minion.
 
@@ -497,6 +595,8 @@ def target(cls, minion_instance, opts, data, connected):
         minion_instance.opts["id"],
         opts["id"],
     )
+    if creds_map:
+        salt.crypt.AsyncAuth.creds_map = creds_map
 
     if not hasattr(minion_instance, "proc_dir"):
         uid = salt.utils.user.get_uid(user=opts.get("user", None))
@@ -965,21 +1065,23 @@ def handle_decoded_payload(self, data):
     instance = self
     multiprocessing_enabled = self.opts.get("multiprocessing", True)
     name = "ProcessPayload(jid={})".format(data["jid"])
+    creds_map = None
     if multiprocessing_enabled:
         if salt.utils.platform.spawning_platform():
             # let python reconstruct the minion on the other side if we"re
             # running on spawning platforms
             instance = None
+            creds_map = salt.crypt.AsyncAuth.creds_map
         with default_signals(signal.SIGINT, signal.SIGTERM):
             process = SignalHandlingProcess(
                 target=target,
-                args=(self, instance, self.opts, data, self.connected),
+                args=(self, instance, self.opts, data, self.connected, creds_map),
                 name=name,
             )
     else:
         process = threading.Thread(
             target=target,
-            args=(self, instance, self.opts, data, self.connected),
+            args=(self, instance, self.opts, data, self.connected, creds_map),
             name=name,
         )
 
@@ -1031,9 +1133,30 @@ def tune_in(self, start=True):
     Lock onto the publisher. This is the main event loop for the minion
     :rtype : None
     """
-    for proxy_id in self.deltaproxy_objs:
-        _proxy_minion = self.deltaproxy_objs[proxy_id]
-        _proxy_minion.setup_scheduler()
-        _proxy_minion.setup_beacons()
-        _proxy_minion._state_run()
+    if self.opts["proxy"].get("parallel_startup"):
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            futures = [
+                executor.submit(subproxy_tune_in, self.deltaproxy_objs[proxy_minion])
+                for proxy_minion in self.deltaproxy_objs
+            ]
+
+        for f in concurrent.futures.as_completed(futures):
+            _proxy_minion = f.result()
+            log.debug("Tune in for sub proxy %r finished", _proxy_minion.opts.get("id"))
+    else:
+        for proxy_minion in self.deltaproxy_objs:
+            _proxy_minion = subproxy_tune_in(self.deltaproxy_objs[proxy_minion])
+            log.debug("Tune in for sub proxy %r finished", _proxy_minion.opts.get("id"))
     super(ProxyMinion, self).tune_in(start=start)
+
+
+def subproxy_tune_in(proxy_minion, start=True):
+    """
+    Tunein sub proxy minions
+    """
+    proxy_minion.setup_scheduler()
+    proxy_minion.setup_beacons()
+    proxy_minion.add_periodic_callback("cleanup", proxy_minion.cleanup_subprocesses)
+    proxy_minion._state_run()
+
+    return proxy_minion
