@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 ACME / Let's Encrypt certificate management state
 =================================================
 
-.. versionadded: 2016.3
+.. versionadded:: 2016.3.0
 
 See also the module documentation
 
@@ -24,41 +23,46 @@ See also the module documentation
         - onchanges_in:
           - cmd: reload-gitlab
 
-'''
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
+"""
+
 import logging
 
+import salt.utils.dictdiffer
+
 log = logging.getLogger(__name__)
 
 
 def __virtual__():
-    '''
+    """
     Only work when the ACME module agrees
-    '''
-    return 'acme.cert' in __salt__
+    """
+    if "acme.cert" in __salt__:
+        return True
+    return (False, "acme module could not be loaded")
 
 
-def cert(name,
-         aliases=None,
-         email=None,
-         webroot=None,
-         test_cert=False,
-         renew=None,
-         keysize=None,
-         server=None,
-         owner='root',
-         group='root',
-         mode='0640',
-         certname=None,
-         preferred_challenges=None,
-         tls_sni_01_port=None,
-         tls_sni_01_address=None,
-         http_01_port=None,
-         http_01_address=None,
-         dns_plugin=None,
-         dns_plugin_credentials=None):
-    '''
+def cert(
+    name,
+    aliases=None,
+    email=None,
+    webroot=None,
+    test_cert=False,
+    renew=None,
+    keysize=None,
+    server=None,
+    owner="root",
+    group="root",
+    mode="0640",
+    certname=None,
+    preferred_challenges=None,
+    tls_sni_01_port=None,
+    tls_sni_01_address=None,
+    http_01_port=None,
+    http_01_address=None,
+    dns_plugin=None,
+    dns_plugin_credentials=None,
+):
+    """
     Obtain/renew a certificate from an ACME CA, probably Let's Encrypt.
 
     :param name: Common Name of the certificate (DNS name of certificate)
@@ -87,75 +91,61 @@ def cert(name,
     :param https_01_address: The address the server listens to during http-01 challenge.
     :param dns_plugin: Name of a DNS plugin to use (currently only 'cloudflare')
     :param dns_plugin_credentials: Path to the credentials file if required by the specified DNS plugin
-    '''
+    """
 
-    if __opts__['test']:
-        ret = {
-            'name': name,
-            'changes': {},
-            'result': None
-        }
-        window = None
-        try:
-            window = int(renew)
-        except Exception:
-            pass
+    if certname is None:
+        certname = name
 
-        comment = 'Certificate {0} '.format(name)
-        if not __salt__['acme.has'](name):
-            comment += 'would have been obtained'
-        elif __salt__['acme.needs_renewal'](name, window):
-            comment += 'would have been renewed'
-        else:
-            comment += 'would not have been touched'
-            ret['result'] = True
-        ret['comment'] = comment
-        return ret
+    ret = {"name": certname, "result": "changeme", "comment": [], "changes": {}}
+    action = None
 
-    if not __salt__['acme.has'](name):
-        old = None
+    current_certificate = {}
+    new_certificate = {}
+    if not __salt__["acme.has"](certname):
+        action = "obtain"
+    elif __salt__["acme.needs_renewal"](certname, renew):
+        action = "renew"
+        current_certificate = __salt__["acme.info"](certname)
     else:
-        old = __salt__['acme.info'](name)
+        ret["result"] = True
+        ret["comment"].append(
+            "Certificate {} exists and does not need renewal.".format(certname)
+        )
 
-    res = __salt__['acme.cert'](
-        name,
-        aliases=aliases,
-        email=email,
-        webroot=webroot,
-        certname=certname,
-        test_cert=test_cert,
-        renew=renew,
-        keysize=keysize,
-        server=server,
-        owner=owner,
-        group=group,
-        mode=mode,
-        preferred_challenges=preferred_challenges,
-        tls_sni_01_port=tls_sni_01_port,
-        tls_sni_01_address=tls_sni_01_address,
-        http_01_port=http_01_port,
-        http_01_address=http_01_address,
-        dns_plugin=dns_plugin,
-        dns_plugin_credentials=dns_plugin_credentials,
-    )
-
-    ret = {
-        'name': name,
-        'result': res['result'] is not False,
-        'comment': res['comment']
-    }
-
-    if res['result'] is None:
-        ret['changes'] = {}
-    else:
-        if not __salt__['acme.has'](name):
-            new = None
+    if action:
+        if __opts__["test"]:
+            ret["result"] = None
+            ret["comment"].append(
+                "Certificate {} would have been {}ed.".format(certname, action)
+            )
+            ret["changes"] = {"old": "current certificate", "new": "new certificate"}
         else:
-            new = __salt__['acme.info'](name)
-
-        ret['changes'] = {
-            'old': old,
-            'new': new
-        }
-
+            res = __salt__["acme.cert"](
+                name,
+                aliases=aliases,
+                email=email,
+                webroot=webroot,
+                certname=certname,
+                test_cert=test_cert,
+                renew=renew,
+                keysize=keysize,
+                server=server,
+                owner=owner,
+                group=group,
+                mode=mode,
+                preferred_challenges=preferred_challenges,
+                tls_sni_01_port=tls_sni_01_port,
+                tls_sni_01_address=tls_sni_01_address,
+                http_01_port=http_01_port,
+                http_01_address=http_01_address,
+                dns_plugin=dns_plugin,
+                dns_plugin_credentials=dns_plugin_credentials,
+            )
+            ret["result"] = res["result"]
+            ret["comment"].append(res["comment"])
+            if ret["result"]:
+                new_certificate = __salt__["acme.info"](certname)
+            ret["changes"] = salt.utils.dictdiffer.deep_diff(
+                current_certificate, new_certificate
+            )
     return ret
