@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Manage kernel packages and active kernel version
 =========================================================================
 
@@ -8,14 +7,14 @@ Example state to install the latest kernel from package repositories:
 .. code-block:: yaml
 
     install-latest-kernel:
-      kernel.latest_installed: []
+      kernelpkg.latest_installed: []
 
 Example state to boot the system if a new kernel has been installed:
 
 .. code-block:: yaml
 
     boot-latest-kernel:
-      kernel.latest_active:
+      kernelpkg.latest_active:
         - at_time: 1
 
 Example state chaining the install and reboot operations:
@@ -23,43 +22,45 @@ Example state chaining the install and reboot operations:
 .. code-block:: yaml
 
     install-latest-kernel:
-      kernel.latest_installed: []
+      kernelpkg.latest_installed: []
 
     boot-latest-kernel:
-      kernel.latest_active:
+      kernelpkg.latest_active:
         - at_time: 1
         - onchanges:
-          - kernel: install-latest-kernel
+          - kernelpkg: install-latest-kernel
 
 Chaining can also be achieved using wait/listen requisites:
 
 .. code-block:: yaml
 
     install-latest-kernel:
-      kernel.latest_installed: []
+      kernelpkg.latest_installed: []
 
     boot-latest-kernel:
-      kernel.latest_wait:
+      kernelpkg.latest_wait:
         - at_time: 1
         - listen:
-          - kernel: install-latest-kernel
-'''
-from __future__ import absolute_import, print_function, unicode_literals
+          - kernelpkg: install-latest-kernel
+"""
+
 import logging
 
 log = logging.getLogger(__name__)
 
 
 def __virtual__():
-    '''
+    """
     Only make these states available if a kernelpkg provider has been detected or
     assigned for this minion
-    '''
-    return 'kernelpkg.upgrade' in __salt__
+    """
+    if "kernelpkg.upgrade" in __salt__:
+        return True
+    return (False, "kernelpkg module could not be loaded")
 
 
 def latest_installed(name, **kwargs):  # pylint: disable=unused-argument
-    '''
+    """
     Ensure that the latest version of the kernel available in the
     repositories is installed.
 
@@ -73,37 +74,40 @@ def latest_installed(name, **kwargs):  # pylint: disable=unused-argument
 
     name
         Arbitrary name for the state. Does not affect behavior.
-    '''
-    installed = __salt__['kernelpkg.list_installed']()
-    upgrade = __salt__['kernelpkg.latest_available']()
-    ret = {'name': name}
+    """
+    installed = __salt__["kernelpkg.list_installed"]()
+    upgrade = __salt__["kernelpkg.latest_available"]()
+    ret = {"name": name}
 
     if upgrade in installed:
-        ret['result'] = True
-        ret['comment'] = ('The latest kernel package is already installed: '
-                          '{0}').format(upgrade)
-        ret['changes'] = {}
+        ret["result"] = True
+        ret["comment"] = "The latest kernel package is already installed: {}".format(
+            upgrade
+        )
+        ret["changes"] = {}
 
     else:
 
-        if __opts__['test']:
-            ret['result'] = None
-            ret['changes'] = {}
-            ret['comment'] = ('The latest kernel package will be installed: '
-                              '{0}').format(upgrade)
+        if __opts__["test"]:
+            ret["result"] = None
+            ret["changes"] = {}
+            ret["comment"] = "The latest kernel package will be installed: {}".format(
+                upgrade
+            )
 
         else:
-            result = __salt__['kernelpkg.upgrade']()
-            ret['result'] = True
-            ret['changes'] = result['upgrades']
-            ret['comment'] = ('The latest kernel package has been installed, '
-                              'but not activated.')
+            result = __salt__["kernelpkg.upgrade"]()
+            ret["result"] = True
+            ret["changes"] = result["upgrades"]
+            ret[
+                "comment"
+            ] = "The latest kernel package has been installed, but not activated."
 
     return ret
 
 
 def latest_active(name, at_time=None, **kwargs):  # pylint: disable=unused-argument
-    '''
+    """
     Initiate a reboot if the running kernel is not the latest one installed.
 
     .. note::
@@ -132,42 +136,38 @@ def latest_active(name, at_time=None, **kwargs):  # pylint: disable=unused-argum
 
     at_time
         The wait time in minutes before the system will be rebooted.
-    '''
-    active = __salt__['kernelpkg.active']()
-    latest = __salt__['kernelpkg.latest_installed']()
-    ret = {'name': name}
+    """
+    active = __salt__["kernelpkg.active"]()
+    latest = __salt__["kernelpkg.latest_installed"]()
+    ret = {"name": name}
 
-    if __salt__['kernelpkg.needs_reboot']():
+    if __salt__["kernelpkg.needs_reboot"]():
 
-        ret['comment'] = ('The system will be booted to activate '
-                          'kernel: {0}').format(latest)
+        ret["comment"] = "The system will be booted to activate kernel: {}".format(
+            latest
+        )
 
-        if __opts__['test']:
-            ret['result'] = None
-            ret['changes'] = {'kernel': {
-                'old': active,
-                'new': latest
-            }}
+        if __opts__["test"]:
+            ret["result"] = None
+            ret["changes"] = {"kernel": {"old": active, "new": latest}}
 
         else:
-            __salt__['system.reboot'](at_time=at_time)
-            ret['result'] = True
-            ret['changes'] = {'kernel': {
-                'old': active,
-                'new': latest
-            }}
+            __salt__["system.reboot"](at_time=at_time)
+            ret["result"] = True
+            ret["changes"] = {"kernel": {"old": active, "new": latest}}
 
     else:
-        ret['result'] = True
-        ret['comment'] = ('The latest installed kernel package '
-                          'is active: {0}').format(active)
-        ret['changes'] = {}
+        ret["result"] = True
+        ret["comment"] = "The latest installed kernel package is active: {}".format(
+            active
+        )
+        ret["changes"] = {}
 
     return ret
 
 
 def latest_wait(name, at_time=None, **kwargs):  # pylint: disable=unused-argument
-    '''
+    """
     Initiate a reboot if the running kernel is not the latest one installed. This is the
     waitable version of :py:func:`~salt.states.kernelpkg.latest_active` and
     will not take any action unless triggered by a watch or listen requesite.
@@ -194,21 +194,22 @@ def latest_wait(name, at_time=None, **kwargs):  # pylint: disable=unused-argumen
 
     at_time
         The wait time in minutes before the system will be rebooted.
-    '''
-    return {'name': name,
-            'changes': {},
-            'result': True,
-            'comment': ''}
+    """
+    return {"name": name, "changes": {}, "result": True, "comment": ""}
 
 
 def mod_watch(name, sfun, **kwargs):
-    '''
+    """
     Execute a kernelpkg state based on a watch or listen call
-    '''
-    if sfun in ('latest_active', 'latest_wait'):
+    """
+    if sfun in ("latest_active", "latest_wait"):
         return latest_active(name, **kwargs)
     else:
-        return {'name': name, 'changes': {},
-                'comment': 'kernelpkg.{0} does not work with the watch '
-                           'requisite.'.format(sfun),
-                'result': False}
+        return {
+            "name": name,
+            "changes": {},
+            "comment": "kernelpkg.{} does not work with the watch requisite.".format(
+                sfun
+            ),
+            "result": False,
+        }
