@@ -1,16 +1,3 @@
-# Copyright 2017 Damon Atkins
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#    http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
 r"""
 Collect information about software installed on Windows OS
 ================
@@ -23,12 +10,6 @@ Collect information about software installed on Windows OS
 
 Known Issue: install_date may not match Control Panel\Programs\Programs and Features
 """
-
-# Note although this code will work with Python 2.7, win32api does not
-# support Unicode. i.e non ASCII characters may be returned with unexpected
-# results e.g. a '?' instead of the correct character
-# Python 3.6 or newer is recommended.
-
 import collections
 import datetime
 import locale
@@ -43,11 +24,11 @@ from functools import cmp_to_key
 __version__ = "0.1"
 
 try:
+    import pywintypes
     import win32api
     import win32con
     import win32process
     import win32security
-    import pywintypes
     import winerror
 
 except ImportError:
@@ -72,11 +53,7 @@ try:
 except ImportError:
     from collections import OrderedDict
 
-try:
-    from salt.utils.versions import LooseVersion
-except ImportError:
-    from distutils.version import LooseVersion  # pylint: disable=blacklisted-module
-
+from salt.utils.versions import Version
 
 # pylint: disable=too-many-instance-attributes
 
@@ -156,38 +133,42 @@ class RegSoftwareInfo:
             self.__reg_32bit_access = (
                 0  # HKEY_USERS does not have a 32bit and 64bit view
             )
-            self.__reg_uninstall_path = (
-                "{}\\Software\\Microsoft\\Windows\\" "CurrentVersion\\Uninstall\\{}"
-            ).format(sid, key_guid)
+            self.__reg_uninstall_path = "{}\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{}".format(
+                sid, key_guid
+            )
             if self.__squid:
-                self.__reg_products_path = "{}\\Software\\Classes\\Installer\\Products\\{}".format(
-                    sid, self.__squid
+                self.__reg_products_path = (
+                    "{}\\Software\\Classes\\Installer\\Products\\{}".format(
+                        sid, self.__squid
+                    )
                 )
-                self.__reg_upgradecode_path = "{}\\Software\\Microsoft\\Installer\\UpgradeCodes".format(
-                    sid
+                self.__reg_upgradecode_path = (
+                    "{}\\Software\\Microsoft\\Installer\\UpgradeCodes".format(sid)
                 )
                 self.__reg_patches_path = (
                     "Software\\Microsoft\\Windows\\CurrentVersion\\Installer\\UserData\\"
-                    "{}\\Products\\{}\\Patches"
-                ).format(sid, self.__squid)
+                    "{}\\Products\\{}\\Patches".format(sid, self.__squid)
+                )
         else:
             self.__reg_hive = "HKEY_LOCAL_MACHINE"
             self.__reg_32bit = use_32bit
             self.__reg_32bit_access = self.__use_32bit_lookup[use_32bit]
-            self.__reg_uninstall_path = "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{}".format(
-                key_guid
+            self.__reg_uninstall_path = (
+                "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{}".format(
+                    key_guid
+                )
             )
             if self.__squid:
-                self.__reg_products_path = "Software\\Classes\\Installer\\Products\\{}".format(
-                    self.__squid
+                self.__reg_products_path = (
+                    "Software\\Classes\\Installer\\Products\\{}".format(self.__squid)
                 )
                 self.__reg_upgradecode_path = (
                     "Software\\Classes\\Installer\\UpgradeCodes"
                 )
                 self.__reg_patches_path = (
                     "Software\\Microsoft\\Windows\\CurrentVersion\\Installer\\UserData\\"
-                    "S-1-5-18\\Products\\{}\\Patches"
-                ).format(self.__squid)
+                    "S-1-5-18\\Products\\{}\\Patches".format(self.__squid)
+                )
 
         # OpenKey is expensive, open in advance and keep it open.
         # This must exist
@@ -490,11 +471,13 @@ class RegSoftwareInfo:
 
             # Check if we have already scanned these upgrade codes before, and also
             # check if they have been updated in the registry since last time we scanned.
-            if have_scan_key in self.__upgrade_code_have_scan and self.__upgrade_code_have_scan[
-                have_scan_key
-            ] == (
-                squid_upgrade_code_all,
-                suc_pytime,
+            if (
+                have_scan_key in self.__upgrade_code_have_scan
+                and self.__upgrade_code_have_scan[have_scan_key]
+                == (
+                    squid_upgrade_code_all,
+                    suc_pytime,
+                )
             ):
                 log.debug(
                     "Scan skipped for upgrade codes, no changes (%s)", have_scan_key
@@ -577,11 +560,13 @@ class RegSoftwareInfo:
             # Scan the patches for the DisplayName of active patches.
             for patch_squid in squid_patch_all:
                 try:
-                    patch_squid_handle = win32api.RegOpenKeyEx(  # pylint: disable=no-member
-                        pat_all_handle,
-                        patch_squid,
-                        0,
-                        win32con.KEY_READ | self.__reg_32bit_access,
+                    patch_squid_handle = (
+                        win32api.RegOpenKeyEx(  # pylint: disable=no-member
+                            pat_all_handle,
+                            patch_squid,
+                            0,
+                            win32con.KEY_READ | self.__reg_32bit_access,
+                        )
                     )
                     (
                         patch_display_name,
@@ -860,14 +845,14 @@ class WinSoftware:
         """
         Used for sorting version numbers oldest to latest
         """
-        return 1 if LooseVersion(ver1) > LooseVersion(ver2) else -1
+        return 1 if Version(ver1) > Version(ver2) else -1
 
     @staticmethod
     def __latest_to_oldest_version(ver1, ver2):
         """
         Used for sorting version numbers, latest to oldest
         """
-        return 1 if LooseVersion(ver1) < LooseVersion(ver2) else -1
+        return 1 if Version(ver1) < Version(ver2) else -1
 
     def pkg_version_list(self, pkg_id):
         """
@@ -1057,7 +1042,11 @@ class WinSoftware:
                     "version capture within object '{}' failed "
                     "for pkg id: '{}' it returned '{}' '{}' "
                     "'{}'".format(
-                        str(self.__pkg_obj), pkg_id, version_str, src, version_user_str,
+                        str(self.__pkg_obj),
+                        pkg_id,
+                        version_str,
+                        src,
+                        version_user_str,
                     )
                 )
 
@@ -1181,7 +1170,7 @@ class WinSoftware:
                     # Not expecting the list to be big, simple search and insert
                     insert_point = 0
                     for ver_item in self.__reg_software[dict_key]:
-                        if LooseVersion(version_text) <= LooseVersion(ver_item):
+                        if Version(version_text) <= Version(ver_item):
                             break
                         insert_point += 1
                     self.__reg_software[dict_key].insert(insert_point, version_text)
@@ -1447,9 +1436,9 @@ class WinSoftware:
 
 def __main():
     """This module can also be run directly for testing
-        Args:
-            detail|list : Provide ``detail`` or version ``list``.
-            system|system+user: System installed and System and User installs.
+    Args:
+        detail|list : Provide ``detail`` or version ``list``.
+        system|system+user: System installed and System and User installs.
     """
     if len(sys.argv) < 3:
         sys.stderr.write(
@@ -1462,9 +1451,10 @@ def __main():
         version_only = True
     if str(sys.argv[2]) == "system+user":
         user_pkgs = True
-    import salt.utils.json
     import timeit
 
+    import salt.utils.json
+
     def run():
         """
         Main run code, when this module is run directly
