@@ -24,6 +24,7 @@ from salt.exceptions import CommandExecutionError, SaltClientError, SaltSystemEx
 
 try:
     import win32file
+
     import salt.utils.win_reg
 except ImportError:
     import resource
@@ -556,6 +557,17 @@ def safe_py_code(code):
     return True
 
 
+def insecure_log():
+    """
+    Return the insecure logs types
+    """
+    insecure = []
+    for level, value in LOG_LEVELS.items():
+        if value < LOG_LEVELS.get("info", 20):
+            insecure.append(level)
+    return insecure
+
+
 def verify_log(opts):
     """
     If an insecre logging configuration is found, show a warning
@@ -573,13 +585,12 @@ def win_verify_env(path, dirs, permissive=False, pki_dir="", skip_extra=False):
     Verify that the named directories are in place and that the environment
     can shake the salt
     """
-    import salt.utils.win_functions
-    import salt.utils.win_dacl
     import salt.utils.path
+    import salt.utils.win_dacl
+    import salt.utils.win_functions
 
     # Make sure the file_roots is not set to something unsafe since permissions
     # on that directory are reset
-
     # `salt.utils.path.safe_path` will consider anything inside `C:\Windows` to
     # be unsafe. In some instances the test suite uses
     # `C:\Windows\Temp\salt-tests-tmpdir\rootdir` as the file_roots. So, we need
